@@ -2,6 +2,7 @@
 // Indexable.cs
 //
 // Copyright (C) 2004 Novell, Inc.
+// Copyright (C) 2007 Debajyoti Bera <dbera.web@gmail.com>
 //
 
 //
@@ -58,6 +59,9 @@ namespace Beagle {
 		// reasons.
 		private IndexableType type = IndexableType.Add;
 
+		// Used to uniquely determine any indexable
+		private int indexable_id = 0;
+
 		// The URI of the item being indexed.
 		private Uri uri = null;
 
@@ -87,7 +91,12 @@ namespace Beagle {
 
 		// Is this being indexed because of crawling or other
 		// background activity?
-		private bool crawled = true;
+		// If set, then the underlying file will be flushed
+		// from buffer cache as soon as it is indexed.
+		// Set it to true when the buffer cache should not
+		// be disturbed due to this indexable (e.g. during
+		// crawling).
+		private bool flush_buffer_cache = false;
 
 		// Is this object inherently contentless?
 		private bool no_content = false;
@@ -133,7 +142,7 @@ namespace Beagle {
 		{
 			this.type = type;
 			this.uri = uri;
-			this.hit_type = "File"; // FIXME: Why do we default to this?
+			this.hit_type = String.Empty;
 		}
 
 		public Indexable (Uri uri) : this (IndexableType.Add, uri)
@@ -158,6 +167,12 @@ namespace Beagle {
 			set { type = value; }
 		}
 
+		[XmlAttribute ("Id")]
+		public int Id {
+			get { return indexable_id; }
+			set { indexable_id = value; }
+		}
+
 		[XmlIgnore]
 		public Uri Uri { 
 			get { return uri; }
@@ -265,10 +280,10 @@ namespace Beagle {
 			get { return ! DeleteContent && ContentUri.IsFile && ParentUri == null; }
 		}
 
-		[XmlAttribute]
-		public bool Crawled {
-			get { return crawled; }
-			set { crawled = value; }
+		[XmlAttribute ("Crawled")]
+		public bool FlushBufferCache {
+			get { return flush_buffer_cache; }
+			set { flush_buffer_cache = value; }
 		}
 
 		[XmlAttribute]
@@ -307,7 +322,7 @@ namespace Beagle {
 			if (DeleteContent) {
 				if (contentUri != null) {
 					if (Debug)
-						Logger.Log.Debug ("Cleaning up {0}", contentUri.LocalPath);
+						Logger.Log.Debug ("Cleaning up {0} ({1})", contentUri.LocalPath, Uri);
 
 					try {
 						File.Delete (contentUri.LocalPath);
@@ -320,7 +335,7 @@ namespace Beagle {
 
 				if (hotContentUri != null) {
 					if (Debug)
-						Logger.Log.Debug ("Cleaning up {0}", hotContentUri.LocalPath);
+						Logger.Log.Debug ("Cleaning up {0} ({1})", hotContentUri.LocalPath, Uri);
 
 					try {
 						File.Delete (hotContentUri.LocalPath);
@@ -445,7 +460,8 @@ namespace Beagle {
 		// merge the two indexables: it just does it.
 		public void Merge (Indexable other)
 		{
-			this.Timestamp = other.Timestamp;
+			if (other.Timestamp > this.Timestamp)
+				this.Timestamp = other.Timestamp;
 
 			foreach (Property prop in other.Properties)
 				this.AddProperty (prop);
@@ -467,6 +483,11 @@ namespace Beagle {
 			if (!this.ValidTimestamp)
 				this.Timestamp = parent.Timestamp;
 
+			if (string.IsNullOrEmpty (this.HitType))
+				this.HitType = parent.HitType;
+
+			this.Source = parent.Source;
+
 			// FIXME: Set all of the parent's properties on the
 			// child so that we get matches against the child
 			// that otherwise would match only the parent, at
