@@ -102,7 +102,7 @@ namespace Beagle.Daemon
 		static Queue pending_directories = new Queue ();
 		static IndexerRequest pending_request;
 		
-		const int BATCH_SIZE = 30;
+		const int BATCH_SIZE = Lucene.Net.Index.IndexWriter.DEFAULT_MAX_BUFFERED_DOCS;
 		
 		/////////////////////////////////////////////////////////
 		
@@ -315,7 +315,8 @@ namespace Beagle.Daemon
 				Environment.Exit (0);
 			}
 
-			string global_files_config = Path.Combine (PathFinder.GlobalConfigDir, Conf.Names.FilesQueryableConfig + ".xml");
+			string global_files_config = Path.Combine (PathFinder.ConfigDataDir, "config-files");
+			global_files_config = Path.Combine (global_files_config, Conf.Names.FilesQueryableConfig + ".xml");
 			if (! File.Exists (global_files_config)) {
 				Log.Error ("Global configuration file not found {0}", global_files_config);
 				Environment.Exit (0);
@@ -353,7 +354,16 @@ namespace Beagle.Daemon
 			fa_store = new FileAttributesStore (backing_fa_store);
 			
 			// Set up signal handlers
+#if MONO_1_9
+			Shutdown.SetupSignalHandlers (delegate (int signal)
+							{
+								if (signal == (int) Mono.Unix.Native.Signum.SIGINT ||
+								    signal == (int) Mono.Unix.Native.Signum.SIGTERM)
+									Shutdown.BeginShutdown ();
+							});
+#else
 			SetupSignalHandlers ();
+#endif
 
 			Thread monitor_thread = null;
 
@@ -641,7 +651,7 @@ namespace Beagle.Daemon
 			Uri uri = UriFu.PathToFileUri (file.FullName);
 			Indexable indexable = new Indexable (uri);
 			indexable.Timestamp = file.LastWriteTimeUtc;
-			indexable.Crawled = true;
+			indexable.FlushBufferCache = true;
 			indexable.AddProperty (Property.NewUnsearched ("fixme:filesize", file.Length));
 			FSQ.AddStandardPropertiesToIndexable (indexable, file.Name, Guid.Empty, false);
 
