@@ -1,9 +1,10 @@
 /*
- * Copyright 2004 The Apache Software Foundation
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  * http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -30,7 +31,7 @@ namespace Lucene.Net.Index
 	public sealed class Term : System.IComparable
 	{
 		internal System.String field;
-		public /*internal*/ System.String text;
+		public System.String text;
 		
 		/// <summary>Constructs a Term with the given field and text. </summary>
 		public Term(System.String fld, System.String txt) : this(fld, txt, true)
@@ -74,7 +75,7 @@ namespace Lucene.Net.Index
 		/// <summary>Compares two terms, returning true iff they have the same
 		/// field and text. 
 		/// </summary>
-		public override bool Equals(System.Object o)
+		public  override bool Equals(System.Object o)
 		{
 			if (o == null)
 				return false;
@@ -119,20 +120,14 @@ namespace Lucene.Net.Index
 			return field + ":" + text;
 		}
 		
-		private void  ReadObject(System.IO.BinaryReader in_Renamed)
+		public void  GetObjectData(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context)
 		{
-			// This function is private and is never been called, so this may not be a port issue.          // {{Aroush-1.4.3}}
-            // 'java.io.ObjectInputStream.defaultReadObject' was not converted                              // {{Aroush-1.4.3}}
-			// in_Renamed.defaultReadObject();                                                              // {{Aroush-1.4.3}}
-			field = String.Intern(field);
+			System.Type thisType = this.GetType();
+			System.Reflection.MemberInfo[] mi = System.Runtime.Serialization.FormatterServices.GetSerializableMembers(thisType, context);
+			for (int i = 0 ; i < mi.Length; i++) 
+			{
+				info.AddValue(mi[i].Name, ((System.Reflection.FieldInfo) mi[i]).GetValue(this));
+			}
 		}
-		
-        // {{Aroush-1.4.3: or is this method is what we want (vs. the above)?!!
-        private void GetObjectData(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context)
-        {
-            info.AddValue("field", field);
-            info.AddValue("text", text);
-        }
-        // Aroush-1.4.3}}
-    }
+	}
 }
\ No newline at end of file
